@@ -5,16 +5,30 @@
 # Resolution:
 #   If the kernel is a Linux kernel, check for the existence of a selection of
 #   files in /etc/ to find the specific flavour.
-#   On SunOS based kernels, return Solaris.
+#   On SunOS based kernels, attempt to determine the flavour, otherwise return Solaris.
 #   On systems other than Linux, use the kernel value.
 #
 # Caveats:
 #
-require 'facter/lsb'
 
 Facter.add(:operatingsystem) do
   confine :kernel => :sunos
-  setcode do "Solaris" end
+  setcode do
+    # Use uname -v because /etc/release can change in zones under SmartOS.
+    # It's apparently not trustworthy enough to rely on for this fact.
+    output = Facter::Util::Resolution.exec('uname -v')
+    if output =~ /^joyent_/
+      "SmartOS"
+    elsif output =~ /^oi_/
+      "OpenIndiana"
+    elsif output =~ /^omnios-/
+      "OmniOS"
+    elsif FileTest.exists?("/etc/debian_version")
+      "Nexenta"
+    else
+      "Solaris"
+    end
+  end
 end
 
 Facter.add(:operatingsystem) do
@@ -24,6 +38,8 @@ Facter.add(:operatingsystem) do
        "Ubuntu"
     elsif FileTest.exists?("/etc/debian_version")
       "Debian"
+    elsif FileTest.exists?("/etc/openwrt_release")
+      "OpenWrt"
     elsif FileTest.exists?("/etc/gentoo-release")
       "Gentoo"
     elsif FileTest.exists?("/etc/fedora-release")
@@ -44,8 +60,6 @@ Facter.add(:operatingsystem) do
       else
         "OEL"
       end
-    elsif FileTest.exists?("/etc/arch-release")
-      "Arch"
     elsif FileTest.exists?("/etc/vmware-release")
       "VMWareESX"
     elsif FileTest.exists?("/etc/redhat-release")
@@ -62,6 +76,8 @@ Facter.add(:operatingsystem) do
         "PSBM"
       elsif txt =~ /Ascendos/i
         "Ascendos"
+      elsif txt =~ /^XenServer/i
+        "XenServer"
       else
         "RedHat"
       end
@@ -84,7 +100,9 @@ Facter.add(:operatingsystem) do
       "Slackware"
     elsif FileTest.exists?("/etc/alpine-release")
       "Alpine"
-    elsif Facter.value(:lsbdistdescription) =~ /Amazon Linux/
+    elsif FileTest.exists?("/etc/mageia-release")
+      "Mageia"
+    elsif FileTest.exists?("/etc/system-release")
       "Amazon"
     end
   end
