@@ -17,6 +17,14 @@ describe "Hardwaremodel fact" do
       Facter.fact(:kernel).stubs(:value).returns("windows")
     end
 
+    it "should detect i486" do
+      cpu = mock('cpu', :Architecture => 0)
+      cpu.expects(:Level).returns(4).twice
+      Facter::Util::WMI.expects(:execquery).returns([cpu])
+
+      Facter.fact(:hardwaremodel).value.should == "i486"
+    end    
+
     it "should detect i686" do
       cpu = mock('cpu', :Architecture => 0, :Level => 6)
       Facter::Util::WMI.expects(:execquery).returns([cpu])
@@ -25,7 +33,7 @@ describe "Hardwaremodel fact" do
     end
 
     it "should detect x64" do
-      cpu = mock('cpu', :Architecture => 9, :AddressWidth => 64)
+      cpu = mock('cpu', :Architecture => 9, :AddressWidth => 64, :Level => 6)
       Facter::Util::WMI.expects(:execquery).returns([cpu])
 
       Facter.fact(:hardwaremodel).value.should == "x64"
@@ -37,5 +45,12 @@ describe "Hardwaremodel fact" do
 
       Facter.fact(:hardwaremodel).value.should == "i686"
     end
+
+    it "(#20989) should report i686 when a 32 bit OS is running on a 64 bit CPU and when level is greater than 6 (and not something like i1586)" do
+      cpu = mock('cpu', :Architecture => 9, :AddressWidth => 32, :Level => 15)
+      Facter::Util::WMI.expects(:execquery).returns([cpu])
+
+      Facter.fact(:hardwaremodel).value.should == "i686"
+    end
   end
 end
