@@ -261,10 +261,15 @@ describe Facter::Util::Virtual do
   end
 
   shared_examples_for "virt-what" do |kernel, path, null_device|
-    Facter.fact(:kernel).stubs(:value).returns(kernel)
-    Facter::Util::Resolution.expects(:which).with("virt-what").returns(path)
-    Facter::Util::Resolution.expects(:exec).with("#{path} 2>#{null_device}")
-    Facter::Util::Virtual.virt_what
+    before(:each) do
+      Facter.fact(:kernel).stubs(:value).returns(kernel)
+      Facter::Util::Resolution.expects(:which).with("virt-what").returns(path)
+      Facter::Util::Resolution.expects(:exec).with("#{path} 2>#{null_device}")
+    end
+
+    it "on #{kernel} virt-what is at #{path} and stderr is sent to #{null_device}" do
+      Facter::Util::Virtual.virt_what
+    end
   end
 
   context "on linux" do
