@@ -304,6 +304,12 @@ describe "Virtual fact" do
       Facter::Util::WMI.expects(:execquery).returns([computersystem])
       Facter.fact(:virtual).value.should == "vmware"
     end
+
+    it "resolves as Xen with a manufacturer name like xen" do
+      computersystem = mock('computersystem', :model => nil, :manufacturer => 'Xen')
+      Facter::Util::WMI.expects(:execquery).returns([computersystem])
+      Facter.fact(:virtual).value.should == "xen"
+    end
   end
 
   describe "with the virt-what command available (#8210)" do
@@ -383,6 +389,12 @@ describe "is_virtual fact" do
     Facter.fact(:is_virtual).value.should == "true"
   end
 
+  it "should be true when running on vserver" do
+    Facter.fact(:kernel).stubs(:value).returns("Linux")
+    Facter.fact(:virtual).stubs(:value).returns("vserver")
+    Facter.fact(:is_virtual).value.should == "true"
+  end
+
   it "should be true when running on kvm" do
     Facter.fact(:kernel).stubs(:value).returns("Linux")
     Facter.fact(:virtual).stubs(:value).returns("kvm")
@@ -432,6 +444,12 @@ describe "is_virtual fact" do
     Facter.fact(:is_virtual).value.should == "false"
   end
 
+  it "should be false on vserver host nodes" do
+    Facter.fact(:kernel).stubs(:value).returns("Linux")
+    Facter.fact(:virtual).stubs(:value).returns("vserver_host")
+    Facter.fact(:is_virtual).value.should == "false"
+  end
+
   it "should be true when running on hyperv" do
     Facter.fact(:kernel).stubs(:value).returns("Linux")
     Facter.fact(:virtual).stubs(:value).returns("hyperv")
